summaryrefslogtreecommitdiffstats
path: root/kmail/kmreaderwin.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:04:28 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:04:28 -0600
commitc5bee2a602f3b6a9ca58c247df52b834ea50d0ed (patch)
treed1c0ded0cabb3d4fdb2ad0e9e68697282eee0dc4 /kmail/kmreaderwin.h
parentb94985f2c07570910ceecd8a0e544460a0de190b (diff)
downloadtdepim-c5bee2a602f3b6a9ca58c247df52b834ea50d0ed.tar.gz
tdepim-c5bee2a602f3b6a9ca58c247df52b834ea50d0ed.zip
Rename kiobuffer and KHTML
Diffstat (limited to 'kmail/kmreaderwin.h')
-rw-r--r--kmail/kmreaderwin.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/kmreaderwin.h b/kmail/kmreaderwin.h
index b8dd3f9f..96199452 100644
--- a/kmail/kmreaderwin.h
+++ b/kmail/kmreaderwin.h
@@ -35,7 +35,7 @@ class KSelectAction;
class KRadioAction;
class KToggleAction;
class TDEConfigBase;
-class KHTMLPart;
+class TDEHTMLPart;
class KURL;
class KMFolder;
@@ -239,7 +239,7 @@ public:
bool isFixedFont() { return mUseFixedFont; }
void setUseFixedFont( bool useFixedFont ) { mUseFixedFont = useFixedFont; }
/** Return the HtmlWriter connected to the KHTMLPart we use */
KMail::HtmlWriter * htmlWriter() { return mHtmlWriter; }
// Action to reply to a message
@@ -279,9 +279,9 @@ public:
void setUpdateAttachment( bool update = true ) { mAtmUpdate = update; }
/** Access to the KHTMLPart used for the viewer. Use with
care! */
- KHTMLPart * htmlPart() const { return mViewer; }
+ TDEHTMLPart * htmlPart() const { return mViewer; }
/** Returns the current message or 0 if none. */
KMMessage* message(KMFolder** folder=0) const;
@@ -554,7 +554,7 @@ private:
TQHBox *mBox;
KMail::HtmlStatusBar *mColorBar;
KMMimePartTree* mMimePartTree;
- KHTMLPart *mViewer;
+ TDEHTMLPart *mViewer;
const KMail::AttachmentStrategy * mAttachmentStrategy;
const KMail::HeaderStrategy * mHeaderStrategy;
@@ -239,7 +239,7 @@ public:
bool isFixedFont() { return mUseFixedFont; }
void setUseFixedFont( bool useFixedFont ) { mUseFixedFont = useFixedFont; }
- /** Return the HtmlWriter connected to the KHTMLPart we use */
+ /** Return the HtmlWriter connected to the TDEHTMLPart we use */
KMail::HtmlWriter * htmlWriter() { return mHtmlWriter; }
// Action to reply to a message
@@ -279,9 +279,9 @@ public:
void setUpdateAttachment( bool update = true ) { mAtmUpdate = update; }
- /** Access to the KHTMLPart used for the viewer. Use with
+ /** Access to the TDEHTMLPart used for the viewer. Use with
care! */